pub fn find_handler(query: &str) -> Result<Box<dyn ArchiveTypePlugin>>Expand description
Look up a handler by canonical name or alias (case-insensitive).
pub fn find_handler(query: &str) -> Result<Box<dyn ArchiveTypePlugin>>Look up a handler by canonical name or alias (case-insensitive).